@@ -107,6 +107,10 @@ impl Default for KeymapConfig {
                     key_sequence: "Z".into(),
                     command: Command::AddSelectedItemToQueue,
                 },
+                Keymap {
+                    key_sequence: "C-g".into(),
+                    command: Command::JumpToHighlightTrackInContext,
+                },
                 Keymap {
                     key_sequence: "C-space".into(),
                     command: Command::ShowActionsOnSelectedItem,
