@@ -1,8 +1,8 @@
 use std::str::FromStr;
 
 use anyhow::Result;
+use ratatui::style;
 use serde::Deserialize;
-use tui::style;
 
 #[derive(Clone, Debug, Deserialize)]
 /// Application theme configurations.
@@ -79,6 +79,7 @@ struct ComponentStyle {
     secondary_row: Option<Style>,
     like: Option<Style>,
     lyrics_played: Option<Style>,
+    lyrics_playing: Option<Style>,
 }
 
 #[derive(Default, Clone, Debug, Deserialize)]
@@ -347,6 +348,18 @@ impl Theme {
             .unwrap_or(&Style::default().modifiers([StyleModifier::Dim]))
             .style(&self.palette)
     }
+
+    pub fn lyrics_playing(&self) -> style::Style {
+        self.component_style
+            .lyrics_playing
+            .as_ref()
+            .unwrap_or(
+                &Style::default()
+                    .fg(StyleColor::Green)
+                    .modifiers([StyleModifier::Bold]),
+            )
+            .style(&self.palette)
+    }
 }
 
 impl Style {
